<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="de_DE">
<context>
    <name>GroupNotify</name>
    <message>
        <source>Clear All</source>
        <translation>Alle Löschen</translation>
    </message>
</context>
<context>
    <name>NotifyHeader</name>
    <message>
        <source>Notification Center</source>
        <translation>Nachrichtenzentrale</translation>
    </message>
    <message>
        <source>Clear All</source>
        <translation>Alle Löschen</translation>
    </message>
</context>
<context>
    <name>NotifySetting</name>
    <message>
        <source>Unpin</source>
        <translation>Abpinnen</translation>
    </message>
    <message>
        <source>Pin</source>
        <translation>Anpinnen</translation>
    </message>
    <message>
        <source>Notification Setting</source>
        <translation>Benachrichtigungs-Einstellungen</translation>
    </message>
</context>
<context>
    <name>notifycenter::AppNotifyItem</name>
    <message>
        <source>Just now</source>
        <translation>Gerade eben</translation>
    </message>
    <message>
        <source>%1 minutes ago</source>
        <translation>vor %1 Minuten</translation>
    </message>
    <message>
        <source>1 hour ago</source>
        <translation>vor 1 Stunde</translation>
    </message>
    <message>
        <source>%1 hours ago</source>
        <translation>vor %1 Stunden</translation>
    </message>
    <message>
        <source>Yesterday </source>
        <translation>Gestern</translation>
    </message>
</context>
</TS>